# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: EntryProtocol.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='EntryProtocol.proto',
  package='com.alibaba.otter.canal.protocol',
  syntax='proto3',
  serialized_options=_b('\n com.alibaba.otter.canal.protocolB\nCanalEntryH\001'),
  serialized_pb=_b('\n\x13\x45ntryProtocol.proto\x12 com.alibaba.otter.canal.protocol\"\xac\x01\n\x05\x45ntry\x12\x38\n\x06header\x18\x01 \x01(\x0b\x32(.com.alibaba.otter.canal.protocol.Header\x12@\n\tentryType\x18\x02 \x01(\x0e\x32+.com.alibaba.otter.canal.protocol.EntryTypeH\x00\x12\x12\n\nstoreValue\x18\x03 \x01(\x0c\x42\x13\n\x11\x65ntryType_present\"\xc3\x03\n\x06Header\x12\x11\n\x07version\x18\x01 \x01(\x05H\x00\x12\x13\n\x0blogfileName\x18\x02 \x01(\t\x12\x15\n\rlogfileOffset\x18\x03 \x01(\x03\x12\x10\n\x08serverId\x18\x04 \x01(\x03\x12\x14\n\x0cserverenCode\x18\x05 \x01(\t\x12\x13\n\x0b\x65xecuteTime\x18\x06 \x01(\x03\x12<\n\nsourceType\x18\x07 \x01(\x0e\x32&.com.alibaba.otter.canal.protocol.TypeH\x01\x12\x12\n\nschemaName\x18\x08 \x01(\t\x12\x11\n\ttableName\x18\t \x01(\t\x12\x13\n\x0b\x65ventLength\x18\n \x01(\x03\x12@\n\teventType\x18\x0b \x01(\x0e\x32+.com.alibaba.otter.canal.protocol.EventTypeH\x02\x12\x35\n\x05props\x18\x0c \x03(\x0b\x32&.com.alibaba.otter.canal.protocol.Pair\x12\x0c\n\x04gtid\x18\r \x01(\tB\x11\n\x0fversion_presentB\x14\n\x12sourceType_presentB\x13\n\x11\x65ventType_present\"\xe3\x01\n\x06\x43olumn\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0f\n\x07sqlType\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05isKey\x18\x04 \x01(\x08\x12\x0f\n\x07updated\x18\x05 \x01(\x08\x12\x10\n\x06isNull\x18\x06 \x01(\x08H\x00\x12\x35\n\x05props\x18\x07 \x03(\x0b\x32&.com.alibaba.otter.canal.protocol.Pair\x12\r\n\x05value\x18\x08 \x01(\t\x12\x0e\n\x06length\x18\t \x01(\x05\x12\x11\n\tmysqlType\x18\n \x01(\tB\x10\n\x0eisNull_present\"\xc1\x01\n\x07RowData\x12?\n\rbeforeColumns\x18\x01 \x03(\x0b\x32(.com.alibaba.otter.canal.protocol.Column\x12>\n\x0c\x61\x66terColumns\x18\x02 \x03(\x0b\x32(.com.alibaba.otter.canal.protocol.Column\x12\x35\n\x05props\x18\x03 \x03(\x0b\x32&.com.alibaba.otter.canal.protocol.Pair\"\xad\x02\n\tRowChange\x12\x0f\n\x07tableId\x18\x01 \x01(\x03\x12@\n\teventType\x18\x02 \x01(\x0e\x32+.com.alibaba.otter.canal.protocol.EventTypeH\x00\x12\x0f\n\x05isDdl\x18\n \x01(\x08H\x01\x12\x0b\n\x03sql\x18\x0b \x01(\t\x12;\n\x08rowDatas\x18\x0c \x03(\x0b\x32).com.alibaba.otter.canal.protocol.RowData\x12\x35\n\x05props\x18\r \x03(\x0b\x32&.com.alibaba.otter.canal.protocol.Pair\x12\x15\n\rddlSchemaName\x18\x0e \x01(\tB\x13\n\x11\x65ventType_presentB\x0f\n\risDdl_present\"\x87\x01\n\x10TransactionBegin\x12\x13\n\x0b\x65xecuteTime\x18\x01 \x01(\x03\x12\x15\n\rtransactionId\x18\x02 \x01(\t\x12\x35\n\x05props\x18\x03 \x03(\x0b\x32&.com.alibaba.otter.canal.protocol.Pair\x12\x10\n\x08threadId\x18\x04 \x01(\x03\"s\n\x0eTransactionEnd\x12\x13\n\x0b\x65xecuteTime\x18\x01 \x01(\x03\x12\x15\n\rtransactionId\x18\x02 \x01(\t\x12\x35\n\x05props\x18\x03 \x03(\x0b\x32&.com.alibaba.otter.canal.protocol.Pair\"\"\n\x04Pair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t*}\n\tEntryType\x12\x1d\n\x19\x45NTRYTYPECOMPATIBLEPROTO2\x10\x00\x12\x14\n\x10TRANSACTIONBEGIN\x10\x01\x12\x0b\n\x07ROWDATA\x10\x02\x12\x12\n\x0eTRANSACTIONEND\x10\x03\x12\r\n\tHEARTBEAT\x10\x04\x12\x0b\n\x07GTIDLOG\x10\x05*\xe5\x01\n\tEventType\x12\x1d\n\x19\x45VENTTYPECOMPATIBLEPROTO2\x10\x00\x12\n\n\x06INSERT\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\n\n\x06\x43REATE\x10\x04\x12\t\n\x05\x41LTER\x10\x05\x12\t\n\x05\x45RASE\x10\x06\x12\t\n\x05QUERY\x10\x07\x12\x0c\n\x08TRUNCATE\x10\x08\x12\n\n\x06RENAME\x10\t\x12\n\n\x06\x43INDEX\x10\n\x12\n\n\x06\x44INDEX\x10\x0b\x12\x08\n\x04GTID\x10\x0c\x12\x0c\n\x08XACOMMIT\x10\r\x12\x0e\n\nXAROLLBACK\x10\x0e\x12\x0e\n\nMHEARTBEAT\x10\x0f*B\n\x04Type\x12\x18\n\x14TYPECOMPATIBLEPROTO2\x10\x00\x12\n\n\x06ORACLE\x10\x01\x12\t\n\x05MYSQL\x10\x02\x12\t\n\x05PGSQL\x10\x03\x42\x30\n com.alibaba.otter.canal.protocolB\nCanalEntryH\x01\x62\x06proto3')
)

_ENTRYTYPE = _descriptor.EnumDescriptor(
  name='EntryType',
  full_name='com.alibaba.otter.canal.protocol.EntryType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENTRYTYPECOMPATIBLEPROTO2', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTIONBEGIN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROWDATA', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTIONEND', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEARTBEAT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GTIDLOG', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1707,
  serialized_end=1832,
)
_sym_db.RegisterEnumDescriptor(_ENTRYTYPE)

EntryType = enum_type_wrapper.EnumTypeWrapper(_ENTRYTYPE)
_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='com.alibaba.otter.canal.protocol.EventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EVENTTYPECOMPATIBLEPROTO2', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INSERT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALTER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERASE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUERY', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRUNCATE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RENAME', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CINDEX', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DINDEX', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GTID', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XACOMMIT', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XAROLLBACK', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MHEARTBEAT', index=15, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1835,
  serialized_end=2064,
)
_sym_db.RegisterEnumDescriptor(_EVENTTYPE)

EventType = enum_type_wrapper.EnumTypeWrapper(_EVENTTYPE)
_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='com.alibaba.otter.canal.protocol.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPECOMPATIBLEPROTO2', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORACLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MYSQL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PGSQL', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2066,
  serialized_end=2132,
)
_sym_db.RegisterEnumDescriptor(_TYPE)

Type = enum_type_wrapper.EnumTypeWrapper(_TYPE)
ENTRYTYPECOMPATIBLEPROTO2 = 0
TRANSACTIONBEGIN = 1
ROWDATA = 2
TRANSACTIONEND = 3
HEARTBEAT = 4
GTIDLOG = 5
EVENTTYPECOMPATIBLEPROTO2 = 0
INSERT = 1
UPDATE = 2
DELETE = 3
CREATE = 4
ALTER = 5
ERASE = 6
QUERY = 7
TRUNCATE = 8
RENAME = 9
CINDEX = 10
DINDEX = 11
GTID = 12
XACOMMIT = 13
XAROLLBACK = 14
MHEARTBEAT = 15
TYPECOMPATIBLEPROTO2 = 0
ORACLE = 1
MYSQL = 2
PGSQL = 3



_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='com.alibaba.otter.canal.protocol.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='com.alibaba.otter.canal.protocol.Entry.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entryType', full_name='com.alibaba.otter.canal.protocol.Entry.entryType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storeValue', full_name='com.alibaba.otter.canal.protocol.Entry.storeValue', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entryType_present', full_name='com.alibaba.otter.canal.protocol.Entry.entryType_present',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=58,
  serialized_end=230,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='com.alibaba.otter.canal.protocol.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='com.alibaba.otter.canal.protocol.Header.version', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logfileName', full_name='com.alibaba.otter.canal.protocol.Header.logfileName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logfileOffset', full_name='com.alibaba.otter.canal.protocol.Header.logfileOffset', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverId', full_name='com.alibaba.otter.canal.protocol.Header.serverId', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverenCode', full_name='com.alibaba.otter.canal.protocol.Header.serverenCode', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executeTime', full_name='com.alibaba.otter.canal.protocol.Header.executeTime', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourceType', full_name='com.alibaba.otter.canal.protocol.Header.sourceType', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schemaName', full_name='com.alibaba.otter.canal.protocol.Header.schemaName', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tableName', full_name='com.alibaba.otter.canal.protocol.Header.tableName', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventLength', full_name='com.alibaba.otter.canal.protocol.Header.eventLength', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventType', full_name='com.alibaba.otter.canal.protocol.Header.eventType', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='props', full_name='com.alibaba.otter.canal.protocol.Header.props', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gtid', full_name='com.alibaba.otter.canal.protocol.Header.gtid', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='version_present', full_name='com.alibaba.otter.canal.protocol.Header.version_present',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='sourceType_present', full_name='com.alibaba.otter.canal.protocol.Header.sourceType_present',
      index=1, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='eventType_present', full_name='com.alibaba.otter.canal.protocol.Header.eventType_present',
      index=2, containing_type=None, fields=[]),
  ],
  serialized_start=233,
  serialized_end=684,
)


_COLUMN = _descriptor.Descriptor(
  name='Column',
  full_name='com.alibaba.otter.canal.protocol.Column',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='com.alibaba.otter.canal.protocol.Column.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sqlType', full_name='com.alibaba.otter.canal.protocol.Column.sqlType', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='com.alibaba.otter.canal.protocol.Column.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isKey', full_name='com.alibaba.otter.canal.protocol.Column.isKey', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated', full_name='com.alibaba.otter.canal.protocol.Column.updated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isNull', full_name='com.alibaba.otter.canal.protocol.Column.isNull', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='props', full_name='com.alibaba.otter.canal.protocol.Column.props', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.otter.canal.protocol.Column.value', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='com.alibaba.otter.canal.protocol.Column.length', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mysqlType', full_name='com.alibaba.otter.canal.protocol.Column.mysqlType', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='isNull_present', full_name='com.alibaba.otter.canal.protocol.Column.isNull_present',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=687,
  serialized_end=914,
)


_ROWDATA = _descriptor.Descriptor(
  name='RowData',
  full_name='com.alibaba.otter.canal.protocol.RowData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='beforeColumns', full_name='com.alibaba.otter.canal.protocol.RowData.beforeColumns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='afterColumns', full_name='com.alibaba.otter.canal.protocol.RowData.afterColumns', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='props', full_name='com.alibaba.otter.canal.protocol.RowData.props', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=917,
  serialized_end=1110,
)


_ROWCHANGE = _descriptor.Descriptor(
  name='RowChange',
  full_name='com.alibaba.otter.canal.protocol.RowChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tableId', full_name='com.alibaba.otter.canal.protocol.RowChange.tableId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventType', full_name='com.alibaba.otter.canal.protocol.RowChange.eventType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isDdl', full_name='com.alibaba.otter.canal.protocol.RowChange.isDdl', index=2,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sql', full_name='com.alibaba.otter.canal.protocol.RowChange.sql', index=3,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rowDatas', full_name='com.alibaba.otter.canal.protocol.RowChange.rowDatas', index=4,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='props', full_name='com.alibaba.otter.canal.protocol.RowChange.props', index=5,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ddlSchemaName', full_name='com.alibaba.otter.canal.protocol.RowChange.ddlSchemaName', index=6,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='eventType_present', full_name='com.alibaba.otter.canal.protocol.RowChange.eventType_present',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='isDdl_present', full_name='com.alibaba.otter.canal.protocol.RowChange.isDdl_present',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=1113,
  serialized_end=1414,
)


_TRANSACTIONBEGIN = _descriptor.Descriptor(
  name='TransactionBegin',
  full_name='com.alibaba.otter.canal.protocol.TransactionBegin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executeTime', full_name='com.alibaba.otter.canal.protocol.TransactionBegin.executeTime', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactionId', full_name='com.alibaba.otter.canal.protocol.TransactionBegin.transactionId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='props', full_name='com.alibaba.otter.canal.protocol.TransactionBegin.props', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='threadId', full_name='com.alibaba.otter.canal.protocol.TransactionBegin.threadId', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1417,
  serialized_end=1552,
)


_TRANSACTIONEND = _descriptor.Descriptor(
  name='TransactionEnd',
  full_name='com.alibaba.otter.canal.protocol.TransactionEnd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executeTime', full_name='com.alibaba.otter.canal.protocol.TransactionEnd.executeTime', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactionId', full_name='com.alibaba.otter.canal.protocol.TransactionEnd.transactionId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='props', full_name='com.alibaba.otter.canal.protocol.TransactionEnd.props', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1554,
  serialized_end=1669,
)


_PAIR = _descriptor.Descriptor(
  name='Pair',
  full_name='com.alibaba.otter.canal.protocol.Pair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.otter.canal.protocol.Pair.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.otter.canal.protocol.Pair.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1671,
  serialized_end=1705,
)

_ENTRY.fields_by_name['header'].message_type = _HEADER
_ENTRY.fields_by_name['entryType'].enum_type = _ENTRYTYPE
_ENTRY.oneofs_by_name['entryType_present'].fields.append(
  _ENTRY.fields_by_name['entryType'])
_ENTRY.fields_by_name['entryType'].containing_oneof = _ENTRY.oneofs_by_name['entryType_present']
_HEADER.fields_by_name['sourceType'].enum_type = _TYPE
_HEADER.fields_by_name['eventType'].enum_type = _EVENTTYPE
_HEADER.fields_by_name['props'].message_type = _PAIR
_HEADER.oneofs_by_name['version_present'].fields.append(
  _HEADER.fields_by_name['version'])
_HEADER.fields_by_name['version'].containing_oneof = _HEADER.oneofs_by_name['version_present']
_HEADER.oneofs_by_name['sourceType_present'].fields.append(
  _HEADER.fields_by_name['sourceType'])
_HEADER.fields_by_name['sourceType'].containing_oneof = _HEADER.oneofs_by_name['sourceType_present']
_HEADER.oneofs_by_name['eventType_present'].fields.append(
  _HEADER.fields_by_name['eventType'])
_HEADER.fields_by_name['eventType'].containing_oneof = _HEADER.oneofs_by_name['eventType_present']
_COLUMN.fields_by_name['props'].message_type = _PAIR
_COLUMN.oneofs_by_name['isNull_present'].fields.append(
  _COLUMN.fields_by_name['isNull'])
_COLUMN.fields_by_name['isNull'].containing_oneof = _COLUMN.oneofs_by_name['isNull_present']
_ROWDATA.fields_by_name['beforeColumns'].message_type = _COLUMN
_ROWDATA.fields_by_name['afterColumns'].message_type = _COLUMN
_ROWDATA.fields_by_name['props'].message_type = _PAIR
_ROWCHANGE.fields_by_name['eventType'].enum_type = _EVENTTYPE
_ROWCHANGE.fields_by_name['rowDatas'].message_type = _ROWDATA
_ROWCHANGE.fields_by_name['props'].message_type = _PAIR
_ROWCHANGE.oneofs_by_name['eventType_present'].fields.append(
  _ROWCHANGE.fields_by_name['eventType'])
_ROWCHANGE.fields_by_name['eventType'].containing_oneof = _ROWCHANGE.oneofs_by_name['eventType_present']
_ROWCHANGE.oneofs_by_name['isDdl_present'].fields.append(
  _ROWCHANGE.fields_by_name['isDdl'])
_ROWCHANGE.fields_by_name['isDdl'].containing_oneof = _ROWCHANGE.oneofs_by_name['isDdl_present']
_TRANSACTIONBEGIN.fields_by_name['props'].message_type = _PAIR
_TRANSACTIONEND.fields_by_name['props'].message_type = _PAIR
DESCRIPTOR.message_types_by_name['Entry'] = _ENTRY
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Column'] = _COLUMN
DESCRIPTOR.message_types_by_name['RowData'] = _ROWDATA
DESCRIPTOR.message_types_by_name['RowChange'] = _ROWCHANGE
DESCRIPTOR.message_types_by_name['TransactionBegin'] = _TRANSACTIONBEGIN
DESCRIPTOR.message_types_by_name['TransactionEnd'] = _TRANSACTIONEND
DESCRIPTOR.message_types_by_name['Pair'] = _PAIR
DESCRIPTOR.enum_types_by_name['EntryType'] = _ENTRYTYPE
DESCRIPTOR.enum_types_by_name['EventType'] = _EVENTTYPE
DESCRIPTOR.enum_types_by_name['Type'] = _TYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
  DESCRIPTOR = _ENTRY,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Entry)
  ))
_sym_db.RegisterMessage(Entry)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
  DESCRIPTOR = _HEADER,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Header)
  ))
_sym_db.RegisterMessage(Header)

Column = _reflection.GeneratedProtocolMessageType('Column', (_message.Message,), dict(
  DESCRIPTOR = _COLUMN,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Column)
  ))
_sym_db.RegisterMessage(Column)

RowData = _reflection.GeneratedProtocolMessageType('RowData', (_message.Message,), dict(
  DESCRIPTOR = _ROWDATA,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.RowData)
  ))
_sym_db.RegisterMessage(RowData)

RowChange = _reflection.GeneratedProtocolMessageType('RowChange', (_message.Message,), dict(
  DESCRIPTOR = _ROWCHANGE,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.RowChange)
  ))
_sym_db.RegisterMessage(RowChange)

TransactionBegin = _reflection.GeneratedProtocolMessageType('TransactionBegin', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTIONBEGIN,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.TransactionBegin)
  ))
_sym_db.RegisterMessage(TransactionBegin)

TransactionEnd = _reflection.GeneratedProtocolMessageType('TransactionEnd', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTIONEND,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.TransactionEnd)
  ))
_sym_db.RegisterMessage(TransactionEnd)

Pair = _reflection.GeneratedProtocolMessageType('Pair', (_message.Message,), dict(
  DESCRIPTOR = _PAIR,
  __module__ = 'EntryProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Pair)
  ))
_sym_db.RegisterMessage(Pair)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import socket
from .connector import IOstreamConnector
from tornado.ioloop import IOLoop
from .protocol import CanalProtocol_pb2
from .protocol import EntryProtocol_pb2
import logging
import platform

LOG = logging.getLogger(__name__)

if platform.system() == 'Windows':
    import asyncio

    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())


class CanalClient(object):

    def __init__(self, host, port, timeout=10):
        self.host = host
        self.port = port
        self.timeout = timeout
        self.io_loop = IOLoop.instance()
        self.get_connector()

    def get_connector(self):
        try:
            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            sock.settimeout(self.timeout)
            self.connector = IOstreamConnector(sock)
            self.connector.set_close_callback(self.on_close)
        except Exception as e:
            LOG.error(e)
            sock.close()
            raise Exception('stream error')

    async def connect(self):
        await self.connector.connect((self.host, self.port))
        data = await self.connector.read_next_packet()
        packet = CanalProtocol_pb2.Packet()
        packet.MergeFromString(data)
        if packet.type != CanalProtocol_pb2.PacketType.HANDSHAKE:
            raise Exception('connect error')
        print('connected to %s:%s' % (self.host, self.port))

    async def reconnect(self):
        self.disconnect()
        await self.connect()

    def disconnect(self):
        if self.connector:
            self.connector.close()
            self.connector = None

    def on_close(self):
        self.disconnect()

    async def check_valid(self, username=b'', password=b''):
        client_auth = CanalProtocol_pb2.ClientAuth()
        client_auth.username = username
        client_auth.password = password

        packet = CanalProtocol_pb2.Packet()
        packet.type = CanalProtocol_pb2.PacketType.CLIENTAUTHENTICATION
        packet.body = client_auth.SerializeToString()

        await self.connector.write_with_header(packet.SerializeToString())

        data = await self.connector.read_next_packet()
        packet = CanalProtocol_pb2.Packet()
        packet.MergeFromString(data)
        if packet.type != CanalProtocol_pb2.PacketType.ACK:
            raise Exception('Auth error')

        ack = CanalProtocol_pb2.Ack()
        ack.MergeFromString(packet.body)
        if ack.error_code > 0:
            raise Exception('something goes wrong when doing authentication. error code:%s, error message:%s' % (
                ack.error_code, ack.error_message))
        print('Auth succed')

    async def subscribe(self, client_id=b'1001', destination=b'example', filter=b'.*\\..*'):
        self.client_id = client_id
        self.destination = destination

        await self.rollback(0)

        sub = CanalProtocol_pb2.Sub()
        sub.destination = destination
        sub.client_id = client_id
        sub.filter = filter

        packet = CanalProtocol_pb2.Packet()
        packet.type = CanalProtocol_pb2.PacketType.SUBSCRIPTION
        packet.body = sub.SerializeToString()

        await self.connector.write_with_header(packet.SerializeToString())

        data = await self.connector.read_next_packet()
        packet = CanalProtocol_pb2.Packet()
        packet.MergeFromString(data)
        if packet.type != CanalProtocol_pb2.PacketType.ACK:
            raise Exception('Subscribe error.')

        ack = CanalProtocol_pb2.Ack()
        ack.MergeFromString(packet.body)
        if ack.error_code > 0:
            raise Exception(
                'Failed to subscribe. error code:%s, error message:%s' % (ack.error_code, ack.error_message))
        print('Subscribe succed')

    def unsubscribe(self):
        pass

    async def get(self, size=100):
        message = await self.get_without_ack(size)
        await self.ack(message['id'])
        return message

    async def get_without_ack(self, batch_size=10, timeout=-1, unit=-1):
        get = CanalProtocol_pb2.Get()
        get.client_id = self.client_id
        get.destination = self.destination
        get.auto_ack = False
        get.fetch_size = batch_size
        get.timeout = timeout
        get.unit = unit

        packet = CanalProtocol_pb2.Packet()
        packet.type = CanalProtocol_pb2.PacketType.GET
        packet.body = get.SerializeToString()

        await self.connector.write_with_header(packet.SerializeToString())

        data = await self.connector.read_next_packet()
        packet = CanalProtocol_pb2.Packet()
        packet.MergeFromString(data)

        message = dict(id=0, entries=[])
        if packet.type == CanalProtocol_pb2.PacketType.MESSAGES:
            messages = CanalProtocol_pb2.Messages()
            messages.MergeFromString(packet.body)
            if messages.batch_id > 0:
                message['id'] = messages.batch_id
                for item in messages.messages:
                    entry = EntryProtocol_pb2.Entry()
                    entry.MergeFromString(item)
                    message['entries'].append(entry)
        elif packet.type == CanalProtocol_pb2.PacketType.ACK:
            ack = CanalProtocol_pb2.PacketType.Ack()
            ack.MergeFromString(packet.body)
            if ack.error_code > 0:
                raise Exception('get data error. error code:%s, error message:%s' % (ack.error_code, ack.error_message))
        else:
            raise Exception('unexpected packet type:%s' % (packet.type))

        return message

    async def ack(self, message_id):
        if message_id:
            clientack = CanalProtocol_pb2.ClientAck()
            clientack.destination = self.destination
            clientack.client_id = self.client_id
            clientack.batch_id = message_id

            packet = CanalProtocol_pb2.Packet()
            packet.type = CanalProtocol_pb2.PacketType.CLIENTACK
            packet.body = clientack.SerializeToString()

            await self.connector.write_with_header(packet.SerializeToString())

    async def rollback(self, batch_id):
        cb = CanalProtocol_pb2.ClientRollback()
        cb.batch_id = batch_id
        cb.client_id = self.client_id
        cb.destination = self.destination

        packet = CanalProtocol_pb2.Packet()
        packet.type = CanalProtocol_pb2.PacketType.CLIENTROLLBACK
        packet.body = cb.SerializeToString()

        await self.connector.write_with_header(packet.SerializeToString())



# -*- coding: utf-8 -*-

from setuptools import setup

with open("README.md", "r",encoding="UTF-8") as fh:
    long_description = fh.read()

setup(
    name="py3canal",
    version="1.0.4",
    packages=["pycanal", "pycanal.protocol"],
    author="vallee",
    author_email="xph_wangly10@163.com",
    license="MIT",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/vallee11/canal-python"
)


# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from tornado.iostream import IOStream
import struct


class IOstreamConnector(IOStream):
    packet_len = 4

    async def read_next_packet(self):
        data = await self.read_bytes(self.packet_len)
        data_len = struct.unpack('>i', data)
        data = await self.read_bytes(data_len[0])
        return data

    async def write_with_header(self, data):
        await self.write(struct.pack('>i', len(data)))
        await self.write(data)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CanalProtocol.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='CanalProtocol.proto',
  package='com.alibaba.otter.canal.protocol',
  syntax='proto3',
  serialized_options=_b('\n com.alibaba.otter.canal.protocolB\013CanalPacketH\001'),
  serialized_pb=_b('\n\x13\x43\x61nalProtocol.proto\x12 com.alibaba.otter.canal.protocol\"\x85\x02\n\x06Packet\x12\x16\n\x0cmagic_number\x18\x01 \x01(\x05H\x00\x12\x11\n\x07version\x18\x02 \x01(\x05H\x01\x12:\n\x04type\x18\x03 \x01(\x0e\x32,.com.alibaba.otter.canal.protocol.PacketType\x12\x44\n\x0b\x63ompression\x18\x04 \x01(\x0e\x32-.com.alibaba.otter.canal.protocol.CompressionH\x02\x12\x0c\n\x04\x62ody\x18\x05 \x01(\x0c\x42\x16\n\x14magic_number_presentB\x11\n\x0fversion_presentB\x15\n\x13\x63ompression_present\"<\n\tHeartBeat\x12\x16\n\x0esend_timestamp\x18\x01 \x01(\x03\x12\x17\n\x0fstart_timestamp\x18\x02 \x01(\x03\"\xad\x01\n\tHandshake\x12 \n\x16\x63ommunication_encoding\x18\x01 \x01(\tH\x00\x12\r\n\x05seeds\x18\x02 \x01(\x0c\x12M\n\x16supported_compressions\x18\x03 \x01(\x0e\x32-.com.alibaba.otter.canal.protocol.CompressionB \n\x1e\x63ommunication_encoding_present\"\xf3\x01\n\nClientAuth\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\x0c\x12\x1a\n\x10net_read_timeout\x18\x03 \x01(\x05H\x00\x12\x1b\n\x11net_write_timeout\x18\x04 \x01(\x05H\x01\x12\x13\n\x0b\x64\x65stination\x18\x05 \x01(\t\x12\x11\n\tclient_id\x18\x06 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x07 \x01(\t\x12\x17\n\x0fstart_timestamp\x18\x08 \x01(\x03\x42\x1a\n\x18net_read_timeout_presentB\x1b\n\x19net_write_timeout_present\"H\n\x03\x41\x63k\x12\x14\n\nerror_code\x18\x01 \x01(\x05H\x00\x12\x15\n\rerror_message\x18\x02 \x01(\tB\x14\n\x12\x65rror_code_present\"E\n\tClientAck\x12\x13\n\x0b\x64\x65stination\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61tch_id\x18\x03 \x01(\x03\"=\n\x03Sub\x12\x13\n\x0b\x64\x65stination\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x07 \x01(\t\"?\n\x05Unsub\x12\x13\n\x0b\x64\x65stination\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x07 \x01(\t\"\xaf\x01\n\x03Get\x12\x13\n\x0b\x64\x65stination\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x12\n\nfetch_size\x18\x03 \x01(\x05\x12\x11\n\x07timeout\x18\x04 \x01(\x03H\x00\x12\x0e\n\x04unit\x18\x05 \x01(\x05H\x01\x12\x12\n\x08\x61uto_ack\x18\x06 \x01(\x08H\x02\x42\x11\n\x0ftimeout_presentB\x0e\n\x0cunit_presentB\x12\n\x10\x61uto_ack_present\".\n\x08Messages\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\x03\x12\x10\n\x08messages\x18\x02 \x03(\x0c\"S\n\x04\x44ump\x12\x0f\n\x07journal\x18\x01 \x01(\t\x12\x10\n\x08position\x18\x02 \x01(\x03\x12\x13\n\ttimestamp\x18\x03 \x01(\x03H\x00\x42\x13\n\x11timestamp_present\"J\n\x0e\x43lientRollback\x12\x13\n\x0b\x64\x65stination\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61tch_id\x18\x03 \x01(\x03*U\n\x0b\x43ompression\x12\x1f\n\x1b\x43OMPRESSIONCOMPATIBLEPROTO2\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x08\n\x04ZLIB\x10\x02\x12\x08\n\x04GZIP\x10\x03\x12\x07\n\x03LZF\x10\x04*\xe7\x01\n\nPacketType\x12\x1f\n\x1bPACKAGETYPECOMPATIBLEPROTO2\x10\x00\x12\r\n\tHANDSHAKE\x10\x01\x12\x18\n\x14\x43LIENTAUTHENTICATION\x10\x02\x12\x07\n\x03\x41\x43K\x10\x03\x12\x10\n\x0cSUBSCRIPTION\x10\x04\x12\x12\n\x0eUNSUBSCRIPTION\x10\x05\x12\x07\n\x03GET\x10\x06\x12\x0c\n\x08MESSAGES\x10\x07\x12\r\n\tCLIENTACK\x10\x08\x12\x0c\n\x08SHUTDOWN\x10\t\x12\x08\n\x04\x44UMP\x10\n\x12\x0e\n\nHEARTBEATS\x10\x0b\x12\x12\n\x0e\x43LIENTROLLBACK\x10\x0c\x42\x31\n com.alibaba.otter.canal.protocolB\x0b\x43\x61nalPacketH\x01\x62\x06proto3')
)

_COMPRESSION = _descriptor.EnumDescriptor(
  name='Compression',
  full_name='com.alibaba.otter.canal.protocol.Compression',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPRESSIONCOMPATIBLEPROTO2', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZLIB', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GZIP', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LZF', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1465,
  serialized_end=1550,
)
_sym_db.RegisterEnumDescriptor(_COMPRESSION)

Compression = enum_type_wrapper.EnumTypeWrapper(_COMPRESSION)
_PACKETTYPE = _descriptor.EnumDescriptor(
  name='PacketType',
  full_name='com.alibaba.otter.canal.protocol.PacketType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PACKAGETYPECOMPATIBLEPROTO2', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HANDSHAKE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENTAUTHENTICATION', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACK', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUBSCRIPTION', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUBSCRIPTION', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MESSAGES', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENTACK', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHUTDOWN', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUMP', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEARTBEATS', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENTROLLBACK', index=12, number=12,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1553,
  serialized_end=1784,
)
_sym_db.RegisterEnumDescriptor(_PACKETTYPE)

PacketType = enum_type_wrapper.EnumTypeWrapper(_PACKETTYPE)
COMPRESSIONCOMPATIBLEPROTO2 = 0
NONE = 1
ZLIB = 2
GZIP = 3
LZF = 4
PACKAGETYPECOMPATIBLEPROTO2 = 0
HANDSHAKE = 1
CLIENTAUTHENTICATION = 2
ACK = 3
SUBSCRIPTION = 4
UNSUBSCRIPTION = 5
GET = 6
MESSAGES = 7
CLIENTACK = 8
SHUTDOWN = 9
DUMP = 10
HEARTBEATS = 11
CLIENTROLLBACK = 12



_PACKET = _descriptor.Descriptor(
  name='Packet',
  full_name='com.alibaba.otter.canal.protocol.Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='magic_number', full_name='com.alibaba.otter.canal.protocol.Packet.magic_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='com.alibaba.otter.canal.protocol.Packet.version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='com.alibaba.otter.canal.protocol.Packet.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compression', full_name='com.alibaba.otter.canal.protocol.Packet.compression', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='com.alibaba.otter.canal.protocol.Packet.body', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='magic_number_present', full_name='com.alibaba.otter.canal.protocol.Packet.magic_number_present',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='version_present', full_name='com.alibaba.otter.canal.protocol.Packet.version_present',
      index=1, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='compression_present', full_name='com.alibaba.otter.canal.protocol.Packet.compression_present',
      index=2, containing_type=None, fields=[]),
  ],
  serialized_start=58,
  serialized_end=319,
)


_HEARTBEAT = _descriptor.Descriptor(
  name='HeartBeat',
  full_name='com.alibaba.otter.canal.protocol.HeartBeat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='send_timestamp', full_name='com.alibaba.otter.canal.protocol.HeartBeat.send_timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='com.alibaba.otter.canal.protocol.HeartBeat.start_timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=381,
)


_HANDSHAKE = _descriptor.Descriptor(
  name='Handshake',
  full_name='com.alibaba.otter.canal.protocol.Handshake',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='communication_encoding', full_name='com.alibaba.otter.canal.protocol.Handshake.communication_encoding', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seeds', full_name='com.alibaba.otter.canal.protocol.Handshake.seeds', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='supported_compressions', full_name='com.alibaba.otter.canal.protocol.Handshake.supported_compressions', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='communication_encoding_present', full_name='com.alibaba.otter.canal.protocol.Handshake.communication_encoding_present',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=384,
  serialized_end=557,
)


_CLIENTAUTH = _descriptor.Descriptor(
  name='ClientAuth',
  full_name='com.alibaba.otter.canal.protocol.ClientAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='com.alibaba.otter.canal.protocol.ClientAuth.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='com.alibaba.otter.canal.protocol.ClientAuth.password', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_read_timeout', full_name='com.alibaba.otter.canal.protocol.ClientAuth.net_read_timeout', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_write_timeout', full_name='com.alibaba.otter.canal.protocol.ClientAuth.net_write_timeout', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='com.alibaba.otter.canal.protocol.ClientAuth.destination', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='com.alibaba.otter.canal.protocol.ClientAuth.client_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='com.alibaba.otter.canal.protocol.ClientAuth.filter', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='com.alibaba.otter.canal.protocol.ClientAuth.start_timestamp', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='net_read_timeout_present', full_name='com.alibaba.otter.canal.protocol.ClientAuth.net_read_timeout_present',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='net_write_timeout_present', full_name='com.alibaba.otter.canal.protocol.ClientAuth.net_write_timeout_present',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=560,
  serialized_end=803,
)


_ACK = _descriptor.Descriptor(
  name='Ack',
  full_name='com.alibaba.otter.canal.protocol.Ack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_code', full_name='com.alibaba.otter.canal.protocol.Ack.error_code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='com.alibaba.otter.canal.protocol.Ack.error_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='error_code_present', full_name='com.alibaba.otter.canal.protocol.Ack.error_code_present',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=805,
  serialized_end=877,
)


_CLIENTACK = _descriptor.Descriptor(
  name='ClientAck',
  full_name='com.alibaba.otter.canal.protocol.ClientAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='destination', full_name='com.alibaba.otter.canal.protocol.ClientAck.destination', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='com.alibaba.otter.canal.protocol.ClientAck.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch_id', full_name='com.alibaba.otter.canal.protocol.ClientAck.batch_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=879,
  serialized_end=948,
)


_SUB = _descriptor.Descriptor(
  name='Sub',
  full_name='com.alibaba.otter.canal.protocol.Sub',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='destination', full_name='com.alibaba.otter.canal.protocol.Sub.destination', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='com.alibaba.otter.canal.protocol.Sub.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='com.alibaba.otter.canal.protocol.Sub.filter', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=950,
  serialized_end=1011,
)


_UNSUB = _descriptor.Descriptor(
  name='Unsub',
  full_name='com.alibaba.otter.canal.protocol.Unsub',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='destination', full_name='com.alibaba.otter.canal.protocol.Unsub.destination', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='com.alibaba.otter.canal.protocol.Unsub.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='com.alibaba.otter.canal.protocol.Unsub.filter', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1013,
  serialized_end=1076,
)


_GET = _descriptor.Descriptor(
  name='Get',
  full_name='com.alibaba.otter.canal.protocol.Get',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='destination', full_name='com.alibaba.otter.canal.protocol.Get.destination', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='com.alibaba.otter.canal.protocol.Get.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fetch_size', full_name='com.alibaba.otter.canal.protocol.Get.fetch_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='com.alibaba.otter.canal.protocol.Get.timeout', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='com.alibaba.otter.canal.protocol.Get.unit', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_ack', full_name='com.alibaba.otter.canal.protocol.Get.auto_ack', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='timeout_present', full_name='com.alibaba.otter.canal.protocol.Get.timeout_present',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='unit_present', full_name='com.alibaba.otter.canal.protocol.Get.unit_present',
      index=1, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='auto_ack_present', full_name='com.alibaba.otter.canal.protocol.Get.auto_ack_present',
      index=2, containing_type=None, fields=[]),
  ],
  serialized_start=1079,
  serialized_end=1254,
)


_MESSAGES = _descriptor.Descriptor(
  name='Messages',
  full_name='com.alibaba.otter.canal.protocol.Messages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_id', full_name='com.alibaba.otter.canal.protocol.Messages.batch_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='messages', full_name='com.alibaba.otter.canal.protocol.Messages.messages', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1302,
)


_DUMP = _descriptor.Descriptor(
  name='Dump',
  full_name='com.alibaba.otter.canal.protocol.Dump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='journal', full_name='com.alibaba.otter.canal.protocol.Dump.journal', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='com.alibaba.otter.canal.protocol.Dump.position', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='com.alibaba.otter.canal.protocol.Dump.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='timestamp_present', full_name='com.alibaba.otter.canal.protocol.Dump.timestamp_present',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1304,
  serialized_end=1387,
)


_CLIENTROLLBACK = _descriptor.Descriptor(
  name='ClientRollback',
  full_name='com.alibaba.otter.canal.protocol.ClientRollback',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='destination', full_name='com.alibaba.otter.canal.protocol.ClientRollback.destination', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='com.alibaba.otter.canal.protocol.ClientRollback.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch_id', full_name='com.alibaba.otter.canal.protocol.ClientRollback.batch_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1389,
  serialized_end=1463,
)

_PACKET.fields_by_name['type'].enum_type = _PACKETTYPE
_PACKET.fields_by_name['compression'].enum_type = _COMPRESSION
_PACKET.oneofs_by_name['magic_number_present'].fields.append(
  _PACKET.fields_by_name['magic_number'])
_PACKET.fields_by_name['magic_number'].containing_oneof = _PACKET.oneofs_by_name['magic_number_present']
_PACKET.oneofs_by_name['version_present'].fields.append(
  _PACKET.fields_by_name['version'])
_PACKET.fields_by_name['version'].containing_oneof = _PACKET.oneofs_by_name['version_present']
_PACKET.oneofs_by_name['compression_present'].fields.append(
  _PACKET.fields_by_name['compression'])
_PACKET.fields_by_name['compression'].containing_oneof = _PACKET.oneofs_by_name['compression_present']
_HANDSHAKE.fields_by_name['supported_compressions'].enum_type = _COMPRESSION
_HANDSHAKE.oneofs_by_name['communication_encoding_present'].fields.append(
  _HANDSHAKE.fields_by_name['communication_encoding'])
_HANDSHAKE.fields_by_name['communication_encoding'].containing_oneof = _HANDSHAKE.oneofs_by_name['communication_encoding_present']
_CLIENTAUTH.oneofs_by_name['net_read_timeout_present'].fields.append(
  _CLIENTAUTH.fields_by_name['net_read_timeout'])
_CLIENTAUTH.fields_by_name['net_read_timeout'].containing_oneof = _CLIENTAUTH.oneofs_by_name['net_read_timeout_present']
_CLIENTAUTH.oneofs_by_name['net_write_timeout_present'].fields.append(
  _CLIENTAUTH.fields_by_name['net_write_timeout'])
_CLIENTAUTH.fields_by_name['net_write_timeout'].containing_oneof = _CLIENTAUTH.oneofs_by_name['net_write_timeout_present']
_ACK.oneofs_by_name['error_code_present'].fields.append(
  _ACK.fields_by_name['error_code'])
_ACK.fields_by_name['error_code'].containing_oneof = _ACK.oneofs_by_name['error_code_present']
_GET.oneofs_by_name['timeout_present'].fields.append(
  _GET.fields_by_name['timeout'])
_GET.fields_by_name['timeout'].containing_oneof = _GET.oneofs_by_name['timeout_present']
_GET.oneofs_by_name['unit_present'].fields.append(
  _GET.fields_by_name['unit'])
_GET.fields_by_name['unit'].containing_oneof = _GET.oneofs_by_name['unit_present']
_GET.oneofs_by_name['auto_ack_present'].fields.append(
  _GET.fields_by_name['auto_ack'])
_GET.fields_by_name['auto_ack'].containing_oneof = _GET.oneofs_by_name['auto_ack_present']
_DUMP.oneofs_by_name['timestamp_present'].fields.append(
  _DUMP.fields_by_name['timestamp'])
_DUMP.fields_by_name['timestamp'].containing_oneof = _DUMP.oneofs_by_name['timestamp_present']
DESCRIPTOR.message_types_by_name['Packet'] = _PACKET
DESCRIPTOR.message_types_by_name['HeartBeat'] = _HEARTBEAT
DESCRIPTOR.message_types_by_name['Handshake'] = _HANDSHAKE
DESCRIPTOR.message_types_by_name['ClientAuth'] = _CLIENTAUTH
DESCRIPTOR.message_types_by_name['Ack'] = _ACK
DESCRIPTOR.message_types_by_name['ClientAck'] = _CLIENTACK
DESCRIPTOR.message_types_by_name['Sub'] = _SUB
DESCRIPTOR.message_types_by_name['Unsub'] = _UNSUB
DESCRIPTOR.message_types_by_name['Get'] = _GET
DESCRIPTOR.message_types_by_name['Messages'] = _MESSAGES
DESCRIPTOR.message_types_by_name['Dump'] = _DUMP
DESCRIPTOR.message_types_by_name['ClientRollback'] = _CLIENTROLLBACK
DESCRIPTOR.enum_types_by_name['Compression'] = _COMPRESSION
DESCRIPTOR.enum_types_by_name['PacketType'] = _PACKETTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Packet = _reflection.GeneratedProtocolMessageType('Packet', (_message.Message,), dict(
  DESCRIPTOR = _PACKET,
  __module__ = 'CanalProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Packet)
  ))
_sym_db.RegisterMessage(Packet)

HeartBeat = _reflection.GeneratedProtocolMessageType('HeartBeat', (_message.Message,), dict(
  DESCRIPTOR = _HEARTBEAT,
  __module__ = 'CanalProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.HeartBeat)
  ))
_sym_db.RegisterMessage(HeartBeat)

Handshake = _reflection.GeneratedProtocolMessageType('Handshake', (_message.Message,), dict(
  DESCRIPTOR = _HANDSHAKE,
  __module__ = 'CanalProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Handshake)
  ))
_sym_db.RegisterMessage(Handshake)

ClientAuth = _reflection.GeneratedProtocolMessageType('ClientAuth', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTAUTH,
  __module__ = 'CanalProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.ClientAuth)
  ))
_sym_db.RegisterMessage(ClientAuth)

Ack = _reflection.GeneratedProtocolMessageType('Ack', (_message.Message,), dict(
  DESCRIPTOR = _ACK,
  __module__ = 'CanalProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Ack)
  ))
_sym_db.RegisterMessage(Ack)

ClientAck = _reflection.GeneratedProtocolMessageType('ClientAck', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTACK,
  __module__ = 'CanalProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.ClientAck)
  ))
_sym_db.RegisterMessage(ClientAck)

Sub = _reflection.GeneratedProtocolMessageType('Sub', (_message.Message,), dict(
  DESCRIPTOR = _SUB,
  __module__ = 'CanalProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Sub)
  ))
_sym_db.RegisterMessage(Sub)

Unsub = _reflection.GeneratedProtocolMessageType('Unsub', (_message.Message,), dict(
  DESCRIPTOR = _UNSUB,
  __module__ = 'CanalProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Unsub)
  ))
_sym_db.RegisterMessage(Unsub)

Get = _reflection.GeneratedProtocolMessageType('Get', (_message.Message,), dict(
  DESCRIPTOR = _GET,
  __module__ = 'CanalProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Get)
  ))
_sym_db.RegisterMessage(Get)

Messages = _reflection.GeneratedProtocolMessageType('Messages', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGES,
  __module__ = 'CanalProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Messages)
  ))
_sym_db.RegisterMessage(Messages)

Dump = _reflection.GeneratedProtocolMessageType('Dump', (_message.Message,), dict(
  DESCRIPTOR = _DUMP,
  __module__ = 'CanalProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.Dump)
  ))
_sym_db.RegisterMessage(Dump)

ClientRollback = _reflection.GeneratedProtocolMessageType('ClientRollback', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTROLLBACK,
  __module__ = 'CanalProtocol_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.otter.canal.protocol.ClientRollback)
  ))
_sym_db.RegisterMessage(ClientRollback)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import time
from pycanal.client import CanalClient
from pycanal.protocol import EntryProtocol_pb2
from tornado.ioloop import IOLoop


async def main():
    while True:
        canal = CanalClient(host="10.88.190.151", port=21111)
        await canal.connect()
        await canal.check_valid()
        await canal.subscribe(client_id=b"14001", destination=b"pandora")
        while True:
            try:
                message = await canal.get(100)
                entries = message["entries"]
                for entry in entries:
                    entry_type = entry.entryType
                    if entry_type in [EntryProtocol_pb2.EntryType.TRANSACTIONBEGIN,
                                      EntryProtocol_pb2.EntryType.TRANSACTIONEND]:
                        continue
                    row_change = EntryProtocol_pb2.RowChange()
                    row_change.MergeFromString(entry.storeValue)
                    header = entry.header
                    database = header.schemaName
                    table = header.tableName
                    event_type = header.eventType

                    for row in row_change.rowDatas:
                        if event_type == EntryProtocol_pb2.EventType.DELETE:
                            format_data = dict()
                            print("delete: {}".format(EntryProtocol_pb2.EventType.DELETE))
                            for column in row.beforeColumns:
                                format_data[column.name] = column.value
                            data = dict(
                                db=database,
                                table=table,
                                event_type=event_type,
                                data=format_data,
                            )
                            print(data)
                        elif event_type == EntryProtocol_pb2.EventType.INSERT:
                            format_data = dict()
                            print("insert: {}".format(EntryProtocol_pb2.EventType.INSERT))
                            for column in row.afterColumns:
                                format_data[column.name] = column.value
                            data = dict(
                                db=database,
                                table=table,
                                event_type=event_type,
                                data=format_data,
                            )
                            print(data)
                        else:
                            format_data = dict()
                            format_data["before"] = format_data["after"] = dict()
                            for column in row.beforeColumns:
                                format_data["before"][column.name] = column.value
                            for column in row.afterColumns:
                                format_data["after"][column.name] = column.value
                            data = dict(
                                db=database,
                                table=table,
                                event_type=event_type,
                                data=format_data,
                            )
                            print(data)
            except Exception as e:
                print(e)
                break
            time.sleep(1)

        canal.disconnect()
        time.sleep(2)


if __name__ == "__main__":
    io_loop = IOLoop.current()
    io_loop.run_sync(main)
